/*
The software in this package is distributed under the GNU General
Public License version 2 (with a special exception described below).

A copy of GNU General Public License (GPL) is included in this distribution,
in the file COPYING.GPL.

As a special exception, if other files instantiate templates or use macros
or inline functions from this file, or you compile this file and link it
with other works to produce a work based on this file, this file
does not by itself cause the resulting work to be covered
by the GNU General Public License.

However the source code for this file must still be made available
in accordance with section (3) of the GNU General Public License.

This exception does not invalidate any other reasons why a work based
on this file might be covered by the GNU General Public License.
*/
/** @file
 * @brief restricts html code to an allowed group of tags.
 *
 * Example of acceptable html code:
 *
    <h1>Restrict HTML</h1>
    <table>
        <tr>
            <th>Tags</th>
            <th>Protocos</th>
        </tr>
        <tr>
            <td>Link</td>
            <td>$10000</td>
        </tr>
    </table>
    <p>Paragraph with <a href="https://example.de"><i>Link</i></a>.</p>
    <br>
    <ul>
        <li>Tags</li>
    </ul>
 *
 *
 * @copyright &copy; Copyright 2017 Intra2net AG
 *
 */

#ifndef __RESTRICTED_HTML_HPP
#define __RESTRICTED_HTML_HPP

#include <string>

namespace I2n
{
    /**
     * @brief Restricts html code to a small list of allowed tags.
     * The attribute "href" from the tag "a" has its value sanitized and if it
     * contains unsafe caracters, the tag is stripped.
     * The link sanitizer adds a redirector in case of an acceptable protocol, strip otherwise.
     * Any other attributes found will result in the tag being stripped.
     * Any comments will be excluded.
     * Strip closing tags that were not open and close tags that were not closed.
     *
     * @param html_code_orig input html code. Non case sensitive.
     * @param strip if true disallowed tags are stripped otherwise throw an error. Defaults to true.
     * @return output html code
     */
    const std::string restrict_html(const std::string &html_code_orig, bool strip=true);

    std::string decode_url(std::string s);

    std::string encode_url(std::string s);

} // eo namespace I2n

#endif
